@@ -40,6 +40,10 @@ static void TableauBtn_down(Widget w, XEvent *xev, String *s, Cardinal *num) {
     button_press((XButtonPressedEvent *)xev);
 }
 /*ARGSUSED*/
+static void TableauBtn_up(Widget w, XEvent *xev, String *s, Cardinal *num) {
+    button_release((XButtonPressedEvent *)xev);
+}
+/*ARGSUSED*/
 static void Redisplay(Widget w, XEvent *xev, Region region) {
     redraw_table((XExposeEvent *)xev);
 }
@@ -48,11 +52,13 @@ static XtActionsRec actions[] = {
     /* {name, procedure}, */
     { "tableau_k",	TableauKey },
     { "tableau_d",	TableauBtn_down },
+    { "tableau_u",	TableauBtn_up },
 };
 
 static char translations[] = "\
 <Key>:		tableau_k()	\n\
 <BtnDown>:	tableau_d()	\n\
+<BtnUp>:	tableau_u()	\n\
 ";
 
 
