@@ -63,6 +63,9 @@ const char *xsok_messages[] = {
     "Least moves: %d, Least pushes: %d, Best score: %d.",
     "This level is unsolved.",
     "Cannot link savegame files.",
+
+    "There is no box.",
+    "There is already a box.",
 };
 
 void read_message_file(const char *filename) {
@@ -128,6 +131,7 @@ static void replace_binding(struct key_action *p, const char *name) {
 	{ "MouseMove",		cmd_MouseMove },	/* requires x, y */
 	{ "MousePush",		cmd_MousePush },	/* requires x, y */
 	{ "MouseUndo",		cmd_MouseUndo },
+	{ "MouseDrag",		cmd_MouseDrag },
 	{ "LevelInfo",		cmd_LevelInfo },
 	{ "DropBookmark",	cmd_DropBookmark },
 	{ "GotoBookmark",	cmd_GotoBookmark },
